LOCALBASE?= /usr

SRCS=	opensmtpd.c iobuf.c ioev.c
HDRS=	opensmtpd.h
MAN=	osmtpd_run.3
LIBDIR?=	${LOCALBASE}/lib/
MANDIR?=	${LOCALBASE}/man/man

BINOWN?=	root
BINGRP?=	root
LIBPERM?=	755

mkfile_path := ${abspath ${lastword ${MAKEFILE_LIST}}}
CURDIR := ${dir ${mkfile_path}}

CFLAGS+=	-fPIC
CFLAGS+=	-I${CURDIR} -I${CURDIR}/openbsd-compat/
CFLAGS+=	-Wall
CFLAGS+=	-Wstrict-prototypes -Wmissing-prototypes
CFLAGS+=	-Wmissing-declarations
CFLAGS+=	-Wshadow -Wpointer-arith -Wcast-qual
CFLAGS+=	-Wsign-compare

LDFLAGS+=	-shared
LDLIBS+=	-levent

INSTALL?=	install

CLEANFILES= ${VERSION_SCRIPT}

VERSION_SCRIPT=	Symbols.map
SYMBOL_LIST=	${CURDIR}/Symbols.list

TARGET_LIB=	libopensmtpd.so

# Defines for OpenBSD-specific interfaces
# Add a OS-specific defines here.
NEED_EXPLICIT_BZERO?=	0
NEED_RECALLOCARRAY?=	1
NEED_REALLOCARRAY?=	0
NEED_STRLCAT?=		1
NEED_STRLCPY?=		1
NEED_STRTONUM?=		1

.PHONY: all
all: ${TARGET_LIB}

includes:
	@cd ${CURDIR}; for i in ${HDRS}; do \
	    j="cmp -s $$i ${DESTDIR}${LOCALBASE}/include/$$i || \
	    ${INSTALL} ${INSTALL_COPY} -o ${BINOWN} -g ${BINGRP} -m 444 $$i\
		${DESTDIR}${LOCALBASE}/include/"; \
	    echo $$j; \
	    eval "$$j"; \
	done;

${SRCS:.c=.d}:%.d:%.c
	 ${CC} ${CFLAGS} -MM $< >$@

ifeq (${NEED_EXPLICIT_BZERO}, 1)
SRCS+=		${CURDIR}/openbsd-compat/explicit_bzero.c
CFLAGS+=	-DNEED_EXPLICIT_BZERO=1

explicit_bzero.o: ${CURDIR}/openbsd-compat/explicit_bzero.c
	${CC} ${CFLAGS} -c -o explicit_bzero.o ${CURDIR}/openbsd-compat/explicit_bzero.c
endif
ifeq (${NEED_RECALLOCARRAY}, 1)
SRCS+=		${CURDIR}/openbsd-compat/recallocarray.c
CFLAGS+=	-DNEED_RECALLOCARRAY=1

recallocarray.o: ${CURDIR}/openbsd-compat/recallocarray.c
	${CC} ${CFLAGS} -c -o recallocarray.o ${CURDIR}/openbsd-compat/recallocarray.c
endif
ifeq (${NEED_REALLOCARRAY}, 1)
SRCS+=		${CURDIR}/openbsd-compat/reallocarray.c
CFLAGS+=	-DNEED_REALLOCARRAY=1

reallocarray.o: ${CURDIR}/openbsd-compat/reallocarray.c
	${CC} ${CFLAGS} -c -o reallocarray.o ${CURDIR}/openbsd-compat/reallocarray.c
endif
ifeq (${NEED_STRLCAT}, 1)
SRCS+=		${CURDIR}/openbsd-compat/strlcat.c
CFLAGS+=	-DNEED_STRLCAT=1

strlcat.o: ${CURDIR}/openbsd-compat/strlcat.c
	${CC} ${CFLAGS} -c -o strlcat.o ${CURDIR}/openbsd-compat/strlcat.c
endif
ifeq (${NEED_STRLCPY}, 1)
SRCS+=		${CURDIR}/openbsd-compat/strlcpy.c
CFLAGS+=	-DNEED_STRLCPY=1

strlcpy.o: ${CURDIR}/openbsd-compat/strlcpy.c
	${CC} ${CFLAGS} -c -o strlcpy.o ${CURDIR}/openbsd-compat/strlcpy.c
endif
ifeq (${NEED_STRTONUM}, 1)
SRCS+=		${CURDIR}/openbsd-compat/strtonum.c
CFLAGS+=	-DNEED_STRTONUM=1

strtonum.o: ${CURDIR}/openbsd-compat/strtonum.c
	${CC} ${CFLAGS} -c -o strtonum.o ${CURDIR}/openbsd-compat/strtonum.c
endif

OBJS=		${notdir ${SRCS:.c=.o}}


${TARGET_LIB}: ${OBJS}
	${CC} ${LDFLAGS} -o $@ $^ ${LDLIBS}

.PHONY: install
install: ${TARGET_LIB}
	${INSTALL} -o ${BINOWN} -g ${BINGRP} -m ${LIBPERM} ${TARGET_LIB} ${LIBDIR}

.PHONY: clean
clean:
	rm -f *.o *.so
